@@ -292,7 +292,7 @@ _api_register( 'row().data()', function ( data ) {
 	row._aData = data;
 
 	// If the DOM has an id, and the data source is an array
-	if ( $.isArray( data ) && row.nTr.id ) {
+	if ( $.isArray( data ) && row.nTr && row.nTr.id ) {
 		_fnSetObjectDataFn( ctx[0].rowId )( data, row.nTr.id );
 	}
 
