@@ -292,7 +292,7 @@ function _fnAjaxUpdateDraw ( settings, json )
 	var recordsTotal    = compat( 'iTotalRecords',        'recordsTotal' );
 	var recordsFiltered = compat( 'iTotalDisplayRecords', 'recordsFiltered' );
 
-	if ( draw ) {
+	if ( draw !== undefined ) {
 		// Protect against out of sequence returns
 		if ( draw*1 < settings.iDraw ) {
 			return;
