@@ -60,6 +60,14 @@ function _fnFeatureHtmlFilter ( settings )
 				_fnThrottle( searchFn, searchDelay ) :
 				searchFn
 		)
+		.on( 'mouseup', function(e) {
+			// Edge fix! Edge 17 does not trigger anything other than mouse events when clicking
+			// on the clear icon (Edge bug 17584515). This is safe in other browsers as `searchFn`
+			// checks the value to see if it has changed. In other browsers it won't have.
+			setTimeout( function () {
+				searchFn.call(jqFilter[0]);
+			}, 10);
+		} )
 		.on( 'keypress.DT', function(e) {
 			/* Prevent form submission */
 			if ( e.keyCode == 13 ) {
