@@ -1107,7 +1107,9 @@ DataTable.defaults = {
 					'DataTables_'+settings.sInstance+'_'+location.pathname
 				)
 			);
-		} catch (e) {}
+		} catch (e) {
+			return {};
+		}
 	},
 
 
