@@ -226,7 +226,12 @@ module.exports = function(config) {
 				'buttons-colVis': {
 					js: 'base/built/DataTables/extensions/Buttons/js/buttons.colVis.js'
 				},
-
+				// External DataTables libraries
+				// Used for performance testing to compare against current builds
+				datatables11018: {
+					js: '//cdn.datatables.net/v/dt/dt-1.10.18/datatables.js',
+					css: '//cdn.datatables.net/v/dt/dt-1.10.18/datatables.css'
+				},
 				// External libraries
 				// Ensure that these are insync with the build/examples.php file
 				jquery: {
@@ -326,5 +331,9 @@ module.exports = function(config) {
 		// Concurrency level
 		// how many browser should be started simultaneous
 		concurrency: Infinity,
+		browserNoActivityTimeout : 120000, //default 10000
+		browserDisconnectTimeout : 120000, // default 2000
+		browserDisconnectTolerance : 1, // default 0
+		captureTimeout: 120000
 	});
 };
